@@ -2,7 +2,6 @@
 A collection of functions for integrating with the Archimedes API
 """
 import json
-import logging
 from http import HTTPStatus
 
 import requests
@@ -17,6 +16,7 @@ from retry.api import retry_call
 
 from archimedes import NoneAuth, get_auth
 from archimedes.configuration import get_api_timeout
+from archimedes.logger import logger
 
 RETRY_EXCEPTIONS = (ConnectionError, ConnectTimeout, HTTPError, Timeout)
 
@@ -34,7 +34,7 @@ class ArchimedesApi:  # pylint:disable=too-few-public-methods
         url,
         method="GET",
         access_token=None,
-        retry_count=3,
+        retry_count=2,
         retry_delay=2,
         **kwargs,
     ):
@@ -51,7 +51,7 @@ class ArchimedesApi:  # pylint:disable=too-few-public-methods
                 authorization token; if None, tries to get the token automatically based
                 on the authentication configuration.
             retry_count:
-                number of times to retry the request.
+                number of times to retry the request. if 0, only one request is made.
             retry_delay:
                 delay between retries in seconds.
             **kwargs:
@@ -60,7 +60,7 @@ class ArchimedesApi:  # pylint:disable=too-few-public-methods
         Returns:
             Response from the API as a python object.
         """
-        logging.debug("Making Archimede API %s request to %s: %s", method, url, kwargs)
+        logger.debug("Making Archimedes API %s request to %s: %s", method, url, kwargs)
         if access_token is None:
             archimedes_auth = get_auth()
             if archimedes_auth is None:
@@ -79,7 +79,7 @@ class ArchimedesApi:  # pylint:disable=too-few-public-methods
             self.session.request,
             fargs=(method, url),
             fkwargs=dict(headers=headers, timeout=timeout, **kwargs),
-            tries=retry_count,
+            tries=retry_count + 1,
             delay=retry_delay,
             exceptions=RETRY_EXCEPTIONS,
         )
@@ -96,8 +96,9 @@ class ArchimedesApi:  # pylint:disable=too-few-public-methods
             except JSONDecodeError:
                 error_message = response.content
             params_str = str(kwargs.get("params"))
+            data_str = str(kwargs.get("data"))
             raise HTTPError(
-                f"API Error while requesting {url} with parameters {params_str}: "
+                f"API Error while requesting {url} with parameters {params_str} and data {data_str}: "
                 f"{error_message}"
             )
 
